#!/bin/bash
## while loop to sleep for a few seconds or forever.
## date: Feb. 02, 2016.
## author: Xiaoxu Guan at LSU HPC.

slptime=3

{ while sleep $slptime; do echo "I'm sleeping for $slptime seconds or forever, ZZZZZ ..."; done ; }

