#!/bin/bash
## list the header info of all bash scripts.
## date: Feb. 01, 2016.
## author: Xiaoxu Guan at LSU HPC.

echo

hi=Hello
sn=Guan
cluster=$1
who=$USER 
no=${#who}
ini=${who:0:1}


Ini=`echo $ini | tr '[:lower:]' '[:upper:]'`

Res=${who:1:$no}
WHO=${Ini}${Res}


echo "$hi" $who"! This is" $cluster"."
echo '$hi' $who'! This is' $cluster'.'
echo '$hi' '$who! This is' $cluster'.'
echo -e '\$hi \$who! This is' '\$cluster''.'
echo -e "\$hi' '\$who! This is '\$cluster''."
echo "$hi" ${WHO} $sn"! This is" $cluster"."


echo
