#!/bin/bash
## Addition of two numbers.
## date: Feb. 02, 2016.
## author: Xiaoxu Guan at LSU HPC.



echo $1 $2

a=$1
b=$2

echo $#

function_add() {
   function_add=$(($a+$b))
}

function_add
echo "$1 + $2 ="  $function_add

