#!/bin/bash
## how to use case in bash script.
## author: Xiaoxu Guan at LSU HPC.
## Jan 30, 2016

echo

case "$1" in
  2015) echo "	==== $1 Calender ==== "; cal $1 ;;
  2016) echo "	==== $1 Calender ====" ; cal $1 ;;
esac

exit 0
