#!/bin/bash
## print Hello world ...
## date: Feb. 01, 2016.
## author: Xiaoxu Guan at LSU HPC.

echo

echo "Hello World!"
echo "Greetings from" $USER "in" `pwd` "on" $HOSTNAME
echo "Today is" `date +"%A %B-%d-%Y"`

echo
